# 1. Introduction
> Simple calculator for solving problems realted to discrete mathmatics, such as combinations, probabilities, truth-tables, and more.
# 2. How to Install
> - pip install -i https://test.pypi.org/simple/ discrete-math-helper
# 3. How to Run
> - python3 calc.py "arguments depending on use"
# 4. Available Arguments
> - Combinations: python3 calc.py combination n r
> - Permutations: python3 calc.py permutation n r
> - Truth Table: python3 calc.py true-table "expression containing p and q"
> - Bayes' Probability: python3 calc.py bayes-prob P(T|A) P(A) P(T)
> - Big O Calculator: python3 calc.py big-o a b d
# 5. Creater Contact Information
> - Email: dokkuh@umich.edu
> - Phone: (479) 544-2885
# 6. Contributors
> - Zalan Shah: zalans@umich.edu
